==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/gl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag…" : "Seleccionar a etiqueta…",
    "Tagged files" : "Ficheiros etiquetados",
    "Select tags to filter by" : "Seleccionar etiquetas polas que filtrar",
    "No tags found" : "Non se atoparon etiquetas",
    "Please select tags to filter by" : "Seleccione etiquetas polas que filtrar",
    "No files found for the selected tags" : "Non se atoparon ficheiros para as etiquetas seleccionadas",
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s engadida polo sistema",
    "Added system tag {systemtag}" : "Engadida a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Engadida a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s engadiu a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} engadiu a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s retirada polo sistema",
    "Removed system tag {systemtag}" : "Retirada a etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Retirada a etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s retirou a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} retirou a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Vostede creou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Vostede creou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Vostede eliminou a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Vostede eliminou a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminou a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminou a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vostede actualizou a etiqueta de sistema  %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vostede actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizou a etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$sfoi engadida a %1$s polo sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} foi engadida a  {file} polo sistema",
    "You added system tag %2$s to %1$s" : "Vostede engadiu a etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Vostede engadiu a etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s engadiu a etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} engadiu a etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s retirada de %1$s polo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} retirada de  {file} polo sistema",
    "You removed system tag %2$s from %1$s" : "Vostede retirou a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vostede retirou a etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s retirou a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} retirou a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrinxida)",
    "%s (invisible)" : "%s (invisíbel)",
    "<strong>System tags</strong> for a file have been modified" : "Modificáronse as <strong>etiquetas de sistemas</strong> dun ficheio",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre usuarios. Moi axeitado para equipos.\n(Se vostede é un provedor cunha instalación de varias instalacións, recoméndase desactivar este aplicativo xa que as etiquetas compártense).",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "As etiquetas colaborativas están dispoñíbeis para todos os usuarios. As etiquetas restrinxidas son visíbeis para os usuarios, mais non poden ser asignadas por eles. As etiquetas invisíbeis son para uso interno, pois os usuarios non poden velas nin asignalas.",
    "Select tag …" : "Seleccionar a etiqueta …",
    "Create a new tag" : "Crear unha nova etiqueta",
    "Name" : "Nome",
    "Public" : "Pública",
    "Restricted" : "Restrinxida",
    "Invisible" : "Invisíbel",
    "Delete" : "Eliminar",
    "Reset" : "Restabelecer",
    "No files in here" : "Aquí non hai ficheiros",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Create and edit collaborative tags. These tags affect all users." : "Crea e edita etiquetas colaborativas. Estas etiquetas afectan a todos os usuarios."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/gl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag…" : "Seleccionar a etiqueta…",
    "Tagged files" : "Ficheiros etiquetados",
    "Select tags to filter by" : "Seleccionar etiquetas polas que filtrar",
    "No tags found" : "Non se atoparon etiquetas",
    "Please select tags to filter by" : "Seleccione as etiquetas polas que filtrar",
    "No files found for the selected tags" : "Non se atoparon ficheiros para as etiquetas seleccionadas",
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s engadida polo sistema",
    "Added system tag {systemtag}" : "Engadida a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Engadida a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s engadiu a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} engadiu a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s retirada polo sistema",
    "Removed system tag {systemtag}" : "Retirada a etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Retirada a etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s retirou a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} retirou a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Vostede creou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Vostede creou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Vostede eliminou a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Vostede eliminou a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminou a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminou a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vostede actualizou a etiqueta de sistema  %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vostede actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizou a etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$sfoi engadida a %1$s polo sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} foi engadida a  {file} polo sistema",
    "You added system tag %2$s to %1$s" : "Vostede engadiu a etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Vostede engadiu a etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s engadiu a etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} engadiu a etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s retirada de %1$s polo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} retirada de  {file} polo sistema",
    "You removed system tag %2$s from %1$s" : "Vostede retirou a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vostede retirou a etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s retirou a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} retirou a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrinxida)",
    "%s (invisible)" : "%s (invisíbel)",
    "<strong>System tags</strong> for a file have been modified" : "Modificáronse as <strong>etiquetas de sistemas</strong> dun ficheio",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre usuarios.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre usuarios. Moi axeitado para equipos.\n(Se vostede é un provedor cunha instalación de varias instalacións, recoméndase desactivar este aplicativo xa que as etiquetas compártense).",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "As etiquetas colaborativas están dispoñíbeis para todos os usuarios. As etiquetas restrinxidas son visíbeis para os usuarios, mais non poden ser asignadas por eles. As etiquetas invisíbeis son para uso interno, pois os usuarios non poden velas nin asignalas.",
    "Select tag …" : "Seleccionar a etiqueta …",
    "Create a new tag" : "Crear unha nova etiqueta",
    "Name" : "Nome",
    "Public" : "Pública",
    "Restricted" : "Restrinxida",
    "Invisible" : "Invisíbel",
    "Delete" : "Eliminar",
    "Reset" : "Restabelecer",
    "No files in here" : "Aquí non hai ficheiros",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Create and edit collaborative tags. These tags affect all users." : "Crea e edita etiquetas colaborativas. Estas etiquetas afectan a todos os usuarios."
},
"nplurals=2; plural=(n != 1);");
